
/*********************************************************************************
*
* SysNucleus : USBTrace Vendor Specific Class Decoder Plugin Sample
* Website: http://www.sysnucleus.com 
* Support: support@sysnucleus.com
*
* DESCRIPTION:
*
* This is a sample DLL code for decoding vendor specific device classes.
* You are allowed to modify this sample to implement your own class decoder.
*
* THINGS TO DO:
*
* You must implement the following 2 functions to use this DLL for
* decoding your device class. 
*
* GetReqName - Fill in the name of the given request (Example : "SetPortDetails") 
*			   in this function. This will be displayed in USBTrace's Log View.
*
* GetReqInfo - Fill in the request's detailed information in this function.
*			   This information will be displayed in USBTrace's Additional 
*			   Information View.
*						
* HELP:
*
* For more information please refer USBTrace help file or
* visit http://www.sysnucleus.com/usbtrace_cd_vendor.html
*
**********************************************************************************/

#include "stdafx.h"
#include "vsdecoder.h"

/*

  Note:-
  The meaning of bmRequestType, bRequest, wValue, wIndex 
  parameters are as per the USB specification (Setup Packet, 8 Bytes)

  [IN] byRequestType	- (Byte) Specifies the direction of data flow,
						   the type of request, and the recipient

  [IN] bRequest			- (Byte) Specifies the request

  [IN] wValue			- (Word) This field is used by the host to 
						  pass information to the device. The meaning
						  of this field depends on the request

  [IN] wIndex			- (Word) This field is used by the host to
						  pass information to the device. A typical
						  use is to pass an index or offset such as an
						  interface or endpoint number. Each request may 
						  define the meaning of this field in different way.

  [IN] pData			- (PVOID) Points to the data transferred during 
						  the data stage of this transfer request

  [IN] nDataLen			- (ULONG) Length of the data


  [OUT] sReqName		- (string) Null terminated string specifying the 
						  request name. 

  [IN] reqNameLenLen	- (USHORT) Length of sReqName 

*/
DLL_EXPORT BOOL GetReqName(UCHAR bmRequestType, UCHAR bRequest,
						   USHORT wValue, USHORT wIndex, 
						   PVOID pData, ULONG nDataLen, 
						   PCHAR sReqName, USHORT reqNameLen)
{
	// You need to fill in sReqName variable in this function.
	// sReqName denotes the name of the request (Ex: "SetPortDetails")
	// This is displayed in the log view. 
	//
	// You have the option to fail this function by returing FALSE, 
	// in which case the request name will not be displayed in the log view.
	//
	// You must fill the sReqName variable based on 
	// bmRequestType, bRequest, wValue, wIndex, pData, nDataLen variables
	//

	// Example:
	// TODO: Replace the following with your own code

	if(bmRequestType == TRANSFER_TYPE_BULKORINTERRUPT)
	{
		// Handle Bulk or Interrupt Packets
		// wValue parameter will contain the endpoint address
		// pData points to data and nDataLen holds data length

		return FALSE; // Not Handled
	}
	else if(bmRequestType == TRANSFER_TYPE_ISOCH)
	{
		// Handle Isochronous Packets
		// wValue parameter will contain the endpoint address
		// pData points to data and nDataLen holds data length

		return FALSE; // Not Handled
	}
	else
	{
		switch(bRequest)
		{

		//case VENDOR_REQUEST_CODE1:
		//	{
		//		strcpy_s(sReqName, reqNameLen, "VendorRequestCode1");
		//	}
		//	break;

		default:
			strcpy_s(sReqName, reqNameLen, "VendorFunction");
		}
	}

	return TRUE;
}

/*

  Note:-
  The meaning of bmRequestType, bRequest, wValue, wIndex 
  parameters are as per the USB specification (Setup Packet, 8 Bytes)

  [IN] byRequestType	- (Byte) Specifies the direction of data flow,
						   the type of request, and the recipient

  [IN] bRequest			- (Byte) Specifies the request

  [IN] wValue			- (Word) This field is used by the host to 
						  pass information to the device. The meaning
						  of this field depends on the request

  [IN] wIndex			- (Word) This field is used by the host to
						  pass information to the device. A typical
						  use is to pass an index or offset such as an
						  interface or endpoint number. Each request may 
						  define the meaning of this field in any way.

  [IN] in				- (BOOL) Request Direction TRUE = To Host; FALSE = To Device


  [IN] pData			- (PVOID) Points to the data transferred during 
						  the data stage of this transfer request

  [IN] nDataLen			- (ULONG) Length of the data


  [OUT] sInfoString		- (string) Null terminated string specifying the 
						  decoded parameters and their values. 

  [IN][OUT] pInfoStringLen	- (PUSHORT) Points to length of sInfoString 
							  If the given pInfoStringLen is insufficient, 
							  fail this function providing the required 
							  length in this parameter. 

*/
DLL_EXPORT BOOL GetReqInfo(UCHAR bmRequestType, UCHAR bRequest,
						   USHORT wValue, USHORT wIndex, BOOL in,
						   PVOID pData, ULONG nDataLen,
						   PCHAR sInfoString, PUSHORT pInfoStringLen)
{

	// You must fill in the detailed request information in sInfoString
	// in the following format:
	//
	// "<Header>;<param1>=<value1>;<param2=value2>"
	//
	// <Header> should be the name of the request 
	// <param1>, <param2> etc are the name of parameters decoded from the request data
	// <value1>, <value2> etc are the values of the parameters
	// 
	// Example:
	// 1. "CBC Wrapper;OpCode=25;Control=0"
	// 2. "CBC Wrapper;OpCode=25(Read Capacity);Control=0(None)"
	//
	// The information which you fill in this string will appear
	// in the additional information view of this request in USBTrace
	//
	// You must fill the sInfoString variable based on 
	// bmRequestType, bRequest, wValue, wIndex, pData, nDataLen variables
	//
	// Please refer USBTrace help file or 
	// visit http://www.sysnucleus.com/usbtrace_cd_vendor.html
	// for more details.

	// Example:
	// TODO: Replace the following with your own code

	if(bmRequestType == TRANSFER_TYPE_BULKORINTERRUPT)
	{
		// Handle Bulk or Interrupt Packets
		// wValue parameter will contain the endpoint address
		// pData points to data and nDataLen holds data length

		return FALSE; // Not Handled
	}
	else if(bmRequestType == TRANSFER_TYPE_ISOCH)
	{
		// Handle Isochronous Packets
		// wValue parameter will contain the endpoint address
		// pData points to data and nDataLen holds data length

		return FALSE; // Not Handled
	}
	else
	{
		switch(bRequest)
		{
		//case VENDOR_REQUEST_CODE1:
		//	{
		//		char sBuffer[10];
		//
		//		// Header
		//		strcpy(sInfoString, "Request Code1");
		//		strcat(sInfoString, ";");
		//
		//		// First Parameter
		//		sprintf(sBuffer, "%d;", pData[0]);
		//		strcat(sInfoString, "Opcode=");
		//		strcat(sInfoString, sBuffer);
		//
		//		// Second Parameter
		//		sprintf(sBuffer, "%d;", pData[1]);
		//		strcat(sInfoString, "Control=");
		//		strcat(sInfoString, sBuffer);
		//	}
		//	break;

		default:
			strcpy_s(sInfoString, *pInfoStringLen, "Header;param1=value1;param2=value2");
		}
	}

	// Note:-
	// pInfoStringLen points to the length of sInfoString during function entry.
	// If you need more space in sInfoString than what is already available, you
	// must fail this function (by returning FALSE) and by filling the required
	// length in pInfoStringLen 

	// Example:-
	//
	//if(*pInfoStringLen < REQUIRED_LENGTH)
	//{
	//	*pInfoStringLen = REQUIRED_LENGTH;
	//	return FALSE;
	//}
	
	return TRUE;
}